KappaNEURON installation from source
====================================

1. Install NEURON 7.4 with Python enabled. The script
   [INSTALL-neuron](./INSTALL-neuron) for will do this on Ubuntu 14.04
   by pulling from the NEURON Mercurial repository.

        ./INSTALL-neuron
        ls

   By default the script installs NEURON in
   `$HOME/nrn/trunk-7.4/nrn/`. The script also installs
   required packages for installation of NEURON and for
   KappaNEURON. The script ends by suggesting a change to the
   `$PYTHONPATH` environment variable, e.g.:

        export PYTHONPATH=$HOME/nrn/7.4/nrn/lib/python/:$PYTHONPATH
        
   This should be added to your shell configuration, e.g. `~/.profile`
   or `~/.bash_profile`.
        
2. Get the latest version of NEURON-compatible SpatialKappa:

        git clone https://github.com/davidcsterratt/SpatialKappa
   
   Follow the [SpatialKappa install instructions](https://github.com/davidcsterratt/SpatialKappa/blob/master/README.md), including
   installation of the python interface. Make a note of the directory
   in which you installed NEURON.
   
3. Within this KappaNEURON directory:

        python2.7 setup.py install

   You can install in a different prefix too, but then you will need
   to make sure that `${PREFIX}/lib/python2.7` is in the `$PYTHONPATH`
   environment variable. E.g.

        PREFIX=/home/username 
        python2.7 setup.py install --prefix=${PREFIX}
        export PYTHONPATH=${PREFIX}/lib/python2.7/site-packages:$PYTHONPATH

Testing
-------

To run all tests from a Linux/Unix environment, run

    make test

from the KappaNEURON directory.

If the `$PYTHONPATH` has not been set as described under step 1 of
*KappaNEURON Installation*, it will need to be set to include the
`$NRNPREFIX` directory in which NEURON was installed. e.g.:

    PYTHONPATH=${NRNPREFIX}/lib/python:${PYTHONPATH} python2.7 -i test_ca_pulse.py

If `make` is not available on your system, try running the following
commands:

    ./test/nrnivmodl.py
	python2.7 -i -m unittest test.TestCaAccumulation.test_injectCalcium
	python2.7 -i -m unittest test.TestCaAccumulation.test_injectCalciumGHK
	python2.7 -i -m unittest test.TestCaAccumulation.test_injectCalciumPump
	python2.7 -i -m unittest test.TestCaAccumulation.test_injectCalciumPumpGHK
	python2.7 -i -m unittest test.TestCaAccumulation.test_injectCalciumPump2

Demonstrations
--------------

# Calcium pulse #

In this demonstration calcium flows into the cell through a channel
that is opened for 10ms, there is a calcium membrane pump, and there
is passive membrane conductance. 

To run the simulation type the following at a command line:

    cd demo/ca_pulse
    ${NRNPREFIX}/x86_64/bin/nrnivmodl
    python2.7 -i test_ca_pulse_run.py

Plots should appear in which the red line (generated by the stochastic
Kappa simulation) is close to the blue line (generated by a
deterministic simulation).

# Postsynaptic proteome #

This demonstration contains a spine attached to a dendritic shaft. The
spine contains NMDA receptors, acitivated by glutamate, as described
in the Kappa file `simple-psd-pepke-kappa-nmda.ka`. This allows
calcium influx, which then binds to calbindin and calmodulin.
Calcium-calmodulin complex binds to CaMKII monomers. CaMKII monomers
can bind and phosphorylate each other. The model of CaM-CaMKII comes
from Pepke et al (2010) PLoS Comp. Biol. 2
http://dx.doi.org/10.1371/journal.pcbi.1000675 . Other sources are
named in the Kappa file.

    cd demo/ca_pulse
    ${NRNPREFIX}/x86_64/bin/nrnivmodl
    python2.7 -i simple-psd-pepke-kappa-nmda.py

<!--  LocalWords:  KappaNEURON SpatialKappa py PYTHONPATH NRNPREFIX
 -->
<!--  LocalWords:  cd proteome FIXME
 -->
